function CookieManager(getSaveDataCallback, savingCallback) {

    this.saveObject = function (saveData) {
        if (!saveData) {
            throw new InvalidArgumentError("saveData", "You're trying to save something that's undefined!");
        }
        if (!saveData.name) {
            throw new InvalidArgumentError("saveData.name", "This saveData object does not contain a name field: " + saveData);
        } else if (typeof saveData.value === "undefined") {
            throw new InvalidArgumentError("saveData.value", "This saveData object does not contain a value field: " + saveData);
        }

        setCookie(saveData.name, saveData.value, 100);
    };

    this.getObject = function (objectName) {
        return getCookie(objectName);
    }

    var self = this;

    this.saveEverything = function () {
        savingCallback(false);
        var t = new Date().getTime();

        var saveData = getSaveDataCallback();
        if (!saveData) {
            if (RENDER_DEBUG_TEXT) {
                console.log("Nothing to save");
            }
        } else if (!typeof saveData === 'Array') {
            throw new OJGLError("The getSaveDataCallback returned an object that was not of the type 'Array'! Received: " + saveData);
        } else {
            if (RENDER_DEBUG_TEXT) {
                console.log("Saving", saveData.length, "objects.")
            }
            for (var data of saveData) {
                self.saveObject(data);
            }
        }

        var savingTime = new Date().getTime() - t;
        var timeoutTime = 500 - savingTime;
        setTimeout(function () {
            savingCallback(true)
        }, timeoutTime);
    };

    setInterval(this.saveEverything, 3000);
    setTimeout(this.saveEverything, 10);

    function setCookie(name, value, daysToSave) {
        var d = new Date();
        d.setTime(d.getTime() + (daysToSave * 24 * 60 * 60 * 1000));
        var expires = "expires=" + d.toUTCString();
        document.cookie = name + "=" + value + "; " + expires;
    }

    function deleteCookie(name) {
        document.cookie = name + "=thisShouldBeDeleted;expires=Thu, 01 Jan 1970 00:00:00 GMT";
    }

    function getCookie(name) {
        name = name + "=";
        var cookies = document.cookie.split(';');
        for (var i = 0; i < cookies.length; i++) {
            var c = cookies[i];
            while (c.charAt(0) == ' ') {
                c = c.substr(1);
            }
            if (c.indexOf(name) == 0) {
                return c.substr(name.length, c.length);
            }
        }
        return "";
    }

    this.deleteEverything = function () {
        var cookies = document.cookie.split(";");
        for (var i = 0; i < cookies.length; i++) {
            var c = cookies[i];
            while (c.charAt(0) == ' ') {
                c = c.substr(1);
            }
            var eq = c.indexOf("=");
            deleteCookie(c.substr(0, eq));
        }
    }
}

CookieManager.prototype.hasSaveFile = function () {
    if (RENDER_DEBUG_TEXT) {
        console.debug("Cookie:", document.cookie);
    }
    return document.cookie.length != 0;
};

CookieManager.prototype.toString = function () {
    return "CookieManager";
};